@@ -39,8 +39,8 @@ void	       ev_window_title_set_type     (EvWindowTitle     *window_title,
 					     EvWindowTitleType  type);
 void           ev_window_title_set_document (EvWindowTitle     *window_title,
 					     EvDocument        *document);
-void	       ev_window_title_set_uri      (EvWindowTitle     *window_title,
-			 		     const char        *uri);
+void	       ev_window_title_set_filename (EvWindowTitle     *window_title,
+					     const char        *filename);
 void	       ev_window_title_free         (EvWindowTitle     *window_title);
 
 G_END_DECLS
